@@ -1,9 +1,11 @@
 package App::ModulePatchUtils;
 
-our $DATE = '2016-06-06'; # DATE
-our $VERSION = '0.001'; # VERSION
+use strict;
 
-use 5.010001;
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2022-08-24'; # DATE
+our $DIST = 'App-ModulePatchUtils'; # DIST
+our $VERSION = '0.002'; # VERSION
 
 1;
 # ABSTRACT: Collection of CLI utilities related to Module::Patch
@@ -20,7 +22,7 @@ App::ModulePatchUtils - Collection of CLI utilities related to Module::Patch
 
 =head1 VERSION
 
-This document describes version 0.001 of App::ModulePatchUtils (from Perl distribution App-ModulePatchUtils), released on 2016-06-06.
+This document describes version 0.002 of App::ModulePatchUtils (from Perl distribution App-ModulePatchUtils), released on 2022-08-24.
 
 =head1 SYNOPSIS
 
@@ -41,14 +43,6 @@ Please visit the project's homepage at L<https://metacpan.org/release/App-Module
 
 Source repository is at L<https://github.com/perlancar/perl-App-ModulePatchUtils>.
 
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-ModulePatchUtils>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
 =head1 SEE ALSO
 
 L<Module::Patch>
@@ -57,11 +51,37 @@ L<Module::Patch>
 
 perlancar <perlancar@cpan.org>
 
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2022, 2016 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-ModulePatchUtils>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =cut
